function y=invscaledata(x,ax,bx)
%
%  Inverse scaling for a matrix which has been scaled with 
%  the function scaledata.
%
%  Input
%    x         scaled matrix
%    ax        information about the scaling
%    bx       
%
%  Output
%    y         the original unscaled data
%
y = diag(ax)\(x - repmat(bx,1,size(x,2)));
